Chat

Struct Chat 

pub struct Chat {
    pub id: i64,
    pub type_: ChatType,
    pub title: Option<String>,
    pub username: Option<String>,
    pub first_name: Option<String>,
    pub last_name: Option<String>,
    pub is_forum: bool,
}
This object represents a chat.

API Reference: link

Fields

id: i64

Unique identifier for this chat. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier.

type_: ChatType

Type of the chat, can be either “private”, “group”, “supergroup” or “channel”

title: Option<String>

Optional. Title, for supergroups, channels and group chats

username: Option<String>

Optional. Username, for private chats, supergroups and channels if available

first_name: Option<String>

Optional. First name of the other party in a private chat

last_name: Option<String>

Optional. Last name of the other party in a private chat

is_forum: bool

Optional. True, if the supergroup chat is a forum (has topics enabled)

Implementations

Source

impl Chat

pub fn full_name(&self) -> String