pub struct ForumTopicCreated {
pub name: String,
pub icon_color: i64,
pub icon_custom_emoji_id: Option<String>,
}Expand description
This object represents a service message about a new forum topic created in the chat.
API Reference: link
Fields
name: StringName of the topic
icon_color: i64Color of the topic icon in RGB format
icon_custom_emoji_id: Option<String>Optional. Unique identifier of the custom emoji shown as the topic icon