pub struct InputLocationMessageContent {
pub latitude: f64,
pub longitude: f64,
pub horizontal_accuracy: Option<f64>,
pub live_period: Option<i64>,
pub heading: Option<i64>,
pub proximity_alert_radius: Option<i64>,
}Expand description
Fields
latitude: f64Latitude of the location in degrees
longitude: f64Longitude of the location in degrees
horizontal_accuracy: Option<f64>Optional. The radius of uncertainty for the location, measured in meters; 0-1500
live_period: Option<i64>Optional. Period in seconds during which the location can be updated, should be between 60 and 86400, or 0x7FFFFFFF for live locations that can be edited indefinitely.
heading: Option<i64>Optional. For live locations, a direction in which the user is moving, in degrees. Must be between 1 and 360 if specified.
proximity_alert_radius: Option<i64>Optional. For live locations, a maximum distance for proximity alerts about approaching another chat member, in meters. Must be between 1 and 100000 if specified.