pub struct LinkPreviewOptions {
pub is_disabled: bool,
pub url: Option<String>,
pub prefer_small_media: bool,
pub prefer_large_media: bool,
pub show_above_text: bool,
}Expand description
Describes the options used for link preview generation.
API Reference: link
Fields
is_disabled: boolOptional. True, if the link preview is disabled
url: Option<String>Optional. URL to use for the link preview. If empty, then the first URL found in the message text will be used
prefer_small_media: boolOptional. True, if the media in the link preview is supposed to be shrunk; ignored if the URL isn’t explicitly specified or media size change isn’t supported for the preview
prefer_large_media: boolOptional. True, if the media in the link preview is supposed to be enlarged; ignored if the URL isn’t explicitly specified or media size change isn’t supported for the preview
show_above_text: boolOptional. True, if the link preview must be shown above the message text; otherwise, the link preview will be shown below the message text
Implementations