pub struct RefundedPayment {
pub total_amount: i64,
pub invoice_payload: String,
pub telegram_payment_charge_id: String,
pub provider_payment_charge_id: Option<String>,
}Expand description
This object contains basic information about a refunded payment.
API Reference: link
Fields
total_amount: i64Total refunded price in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45, total_amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).
invoice_payload: StringBot-specified invoice payload
telegram_payment_charge_id: StringTelegram payment identifier
provider_payment_charge_id: Option<String>Optional. Provider payment identifier