Module approve_chat_join_request

Module approve_chat_join_request 

Structs

ApproveChatJoinRequestParams
ApproveChatJoinRequestRequest
Use this method to approve a chat join request. The bot must be an administrator in the chat for this to work and must have the can_invite_users administrator right. Returns True on success.