pub struct ApproveChatJoinRequestRequest<'a> { /* private fields */ }Expand description
Use this method to approve a chat join request. The bot must be an administrator in the chat for this to work and must have the can_invite_users administrator right. Returns True on success.
Implementations
Sourceimpl<'a> ApproveChatJoinRequestRequest<'a>
impl<'a> ApproveChatJoinRequestRequest<'a>