SendInvoiceRequest

Struct SendInvoiceRequest 

pub struct SendInvoiceRequest<'a> { /* private fields */ }
Use this method to send invoices. On success, the sent Message is returned.

Implementations

Source

impl<'a> SendInvoiceRequest<'a>

pub fn new( api: &'a API, chat_id: impl Into<ChatId>, title: impl Into<String>, description: impl Into<String>, payload: impl Into<String>, currency: impl Into<String>, prices: impl IntoIterator<Item = impl Into<LabeledPrice>>, ) -> Self

pub fn chat_id(self, chat_id: impl Into<ChatId>) -> Self

Unique identifier for the target chat or username of the target channel (in the format @channelusername)

pub fn message_thread_id(self, message_thread_id: impl Into<i64>) -> Self

Unique identifier for the target message thread (topic) of the forum; for forum supergroups only

pub fn title(self, title: impl Into<String>) -> Self

Product name, 1-32 characters

pub fn description(self, description: impl Into<String>) -> Self

Product description, 1-255 characters

pub fn payload(self, payload: impl Into<String>) -> Self

Bot-defined invoice payload, 1-128 bytes. This will not be displayed to the user, use it for your internal processes.

pub fn provider_token(self, provider_token: impl Into<String>) -> Self

Payment provider token, obtained via @BotFather. Pass an empty string for payments in Telegram Stars.

pub fn currency(self, currency: impl Into<String>) -> Self

Three-letter ISO 4217 currency code, see more on currencies. Pass “XTR” for payments in Telegram Stars.

pub fn prices( self, prices: impl IntoIterator<Item = impl Into<LabeledPrice>>, ) -> Self

Price breakdown, a JSON-serialized list of components (e.g. product price, tax, discount, delivery cost, delivery tax, bonus, etc.). Must contain exactly one item for payments in Telegram Stars.

pub fn max_tip_amount(self, max_tip_amount: impl Into<i64>) -> Self

The maximum accepted amount for tips in the smallest units of the currency (integer, not float/double). For example, for a maximum tip of US$ 1.45 pass max_tip_amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies). Defaults to 0. Not supported for payments in Telegram Stars.

pub fn suggested_tip_amounts( self, suggested_tip_amounts: impl IntoIterator<Item = impl Into<i64>>, ) -> Self

A JSON-serialized array of suggested amounts of tips in the smallest units of the currency (integer, not float/double). At most 4 suggested tip amounts can be specified. The suggested tip amounts must be positive, passed in a strictly increased order and must not exceed max_tip_amount.

pub fn start_parameter(self, start_parameter: impl Into<String>) -> Self

Unique deep-linking parameter. If left empty, forwarded copies of the sent message will have a Pay button, allowing multiple users to pay directly from the forwarded message, using the same invoice. If non-empty, forwarded copies of the sent message will have a URL button with a deep link to the bot (instead of a Pay button), with the value used as the start parameter

pub fn provider_data(self, provider_data: impl Into<String>) -> Self

JSON-serialized data about the invoice, which will be shared with the payment provider. A detailed description of required fields should be provided by the payment provider.

pub fn photo_url(self, photo_url: impl Into<String>) -> Self

URL of the product photo for the invoice. Can be a photo of the goods or a marketing image for a service. People like it better when they see what they are paying for.

pub fn photo_size(self, photo_size: impl Into<i64>) -> Self

Photo size in bytes

pub fn photo_width(self, photo_width: impl Into<i64>) -> Self

Photo width

pub fn photo_height(self, photo_height: impl Into<i64>) -> Self

Photo height

pub fn need_name(self, need_name: impl Into<bool>) -> Self

Pass True if you require the user’s full name to complete the order. Ignored for payments in Telegram Stars.

pub fn need_phone_number(self, need_phone_number: impl Into<bool>) -> Self

Pass True if you require the user’s phone number to complete the order. Ignored for payments in Telegram Stars.

pub fn need_email(self, need_email: impl Into<bool>) -> Self

Pass True if you require the user’s email address to complete the order. Ignored for payments in Telegram Stars.

pub fn need_shipping_address( self, need_shipping_address: impl Into<bool>, ) -> Self

Pass True if you require the user’s shipping address to complete the order. Ignored for payments in Telegram Stars.

pub fn send_phone_number_to_provider( self, send_phone_number_to_provider: impl Into<bool>, ) -> Self

Pass True if the user’s phone number should be sent to the provider. Ignored for payments in Telegram Stars.

pub fn send_email_to_provider( self, send_email_to_provider: impl Into<bool>, ) -> Self

Pass True if the user’s email address should be sent to the provider. Ignored for payments in Telegram Stars.

pub fn is_flexible(self, is_flexible: impl Into<bool>) -> Self

Pass True if the final price depends on the shipping method. Ignored for payments in Telegram Stars.

pub fn disable_notification(self, disable_notification: impl Into<bool>) -> Self

Sends the message silently. Users will receive a notification with no sound.

pub fn protect_content(self, protect_content: impl Into<bool>) -> Self

Protects the contents of the sent message from forwarding and saving

pub fn allow_paid_broadcast(self, allow_paid_broadcast: impl Into<bool>) -> Self

Pass True to allow up to 1000 messages per second, ignoring broadcasting limits for a fee of 0.1 Telegram Stars per message. The relevant Stars will be withdrawn from the bot’s balance

pub fn message_effect_id(self, message_effect_id: impl Into<String>) -> Self

Unique identifier of the message effect to be added to the message; for private chats only

pub fn reply_parameters( self, reply_parameters: impl Into<ReplyParameters>, ) -> Self

Description of the message to reply to

pub fn reply_markup(self, reply_markup: impl Into<InlineKeyboardMarkup>) -> Self

A JSON-serialized object for an inline keyboard. If empty, one ‘Pay total price’ button will be shown. If not empty, the first button must be a Pay button.