pub struct SetChatStickerSetRequest<'a> { /* private fields */ }Expand description
Use this method to set a new group sticker set for a supergroup. The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights. Use the field can_set_sticker_set optionally returned in getChat requests to check if the bot can use this method. Returns True on success.
Implementations
Sourceimpl<'a> SetChatStickerSetRequest<'a>
impl<'a> SetChatStickerSetRequest<'a>
pub fn new( api: &'a API, chat_id: impl Into<ChatId>, sticker_set_name: impl Into<String>, ) -> Self
Sourcepub fn chat_id(self, chat_id: impl Into<ChatId>) -> Self
pub fn chat_id(self, chat_id: impl Into<ChatId>) -> Self
Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)
Sourcepub fn sticker_set_name(self, sticker_set_name: impl Into<String>) -> Self
pub fn sticker_set_name(self, sticker_set_name: impl Into<String>) -> Self
Name of the sticker set to be set as the group sticker set