pub struct SetStickerEmojiListRequest<'a> { /* private fields */ }Expand description
Use this method to change the list of emoji assigned to a regular or custom emoji sticker. The sticker must belong to a sticker set created by the bot. Returns True on success.
Implementations
Sourceimpl<'a> SetStickerEmojiListRequest<'a>
impl<'a> SetStickerEmojiListRequest<'a>
pub fn new( api: &'a API, sticker: impl Into<String>, emoji_list: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Sourcepub fn emoji_list(
self,
emoji_list: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn emoji_list( self, emoji_list: impl IntoIterator<Item = impl Into<String>>, ) -> Self
A JSON-serialized list of 1-20 emoji associated with the sticker