pub struct UnhideGeneralForumTopicRequest<'a> { /* private fields */ }Expand description
Use this method to unhide the ‘General’ topic in a forum supergroup chat. The bot must be an administrator in the chat for this to work and must have the can_manage_topics administrator rights. Returns True on success.
Implementations