pub struct ForwardMessageRequest<'a> { /* private fields */ }Expand description
Use this method to forward messages of any kind. Service messages and messages with protected content can’t be forwarded. On success, the sent Message is returned.
Implementations
Sourceimpl<'a> ForwardMessageRequest<'a>
impl<'a> ForwardMessageRequest<'a>
pub fn new( api: &'a API, chat_id: impl Into<ChatId>, from_chat_id: impl Into<ChatId>, message_id: impl Into<i64>, ) -> Self
Sourcepub fn chat_id(self, chat_id: impl Into<ChatId>) -> Self
pub fn chat_id(self, chat_id: impl Into<ChatId>) -> Self
Unique identifier for the target chat or username of the target channel (in the format @channelusername)
Sourcepub fn message_thread_id(self, message_thread_id: impl Into<i64>) -> Self
pub fn message_thread_id(self, message_thread_id: impl Into<i64>) -> Self
Unique identifier for the target message thread (topic) of the forum; for forum supergroups only
Sourcepub fn from_chat_id(self, from_chat_id: impl Into<ChatId>) -> Self
pub fn from_chat_id(self, from_chat_id: impl Into<ChatId>) -> Self
Unique identifier for the chat where the original message was sent (or channel username in the format @channelusername)
Sourcepub fn disable_notification(self, disable_notification: impl Into<bool>) -> Self
pub fn disable_notification(self, disable_notification: impl Into<bool>) -> Self
Sends the message silently. Users will receive a notification with no sound.
Sourcepub fn protect_content(self, protect_content: impl Into<bool>) -> Self
pub fn protect_content(self, protect_content: impl Into<bool>) -> Self
Protects the contents of the forwarded message from forwarding and saving
Sourcepub fn message_id(self, message_id: impl Into<i64>) -> Self
pub fn message_id(self, message_id: impl Into<i64>) -> Self
Message identifier in the chat specified in from_chat_id