pub struct RestrictChatMemberRequest<'a> { /* private fields */ }Expand description
Use this method to restrict a user in a supergroup. The bot must be an administrator in the supergroup for this to work and must have the appropriate administrator rights. Pass True for all permissions to lift restrictions from a user. Returns True on success.
Implementations
Sourceimpl<'a> RestrictChatMemberRequest<'a>
impl<'a> RestrictChatMemberRequest<'a>
pub fn new( api: &'a API, chat_id: impl Into<ChatId>, user_id: impl Into<i64>, permissions: impl Into<ChatPermissions>, ) -> Self
Sourcepub fn chat_id(self, chat_id: impl Into<ChatId>) -> Self
pub fn chat_id(self, chat_id: impl Into<ChatId>) -> Self
Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)
Sourcepub fn permissions(self, permissions: impl Into<ChatPermissions>) -> Self
pub fn permissions(self, permissions: impl Into<ChatPermissions>) -> Self
A JSON-serialized object for new user permissions
Sourcepub fn use_independent_chat_permissions(
self,
use_independent_chat_permissions: impl Into<bool>,
) -> Self
pub fn use_independent_chat_permissions( self, use_independent_chat_permissions: impl Into<bool>, ) -> Self
Pass True if chat permissions are set independently. Otherwise, the can_send_other_messages and can_add_web_page_previews permissions will imply the can_send_messages, can_send_audios, can_send_documents, can_send_photos, can_send_videos, can_send_video_notes, and can_send_voice_notes permissions; the can_send_polls permission will imply the can_send_messages permission.
Sourcepub fn until_date(self, until_date: impl Into<i64>) -> Self
pub fn until_date(self, until_date: impl Into<i64>) -> Self
Date when restrictions will be lifted for the user; Unix time. If user is restricted for more than 366 days or less than 30 seconds from the current time, they are considered to be restricted forever