pub struct SendAudioRequest<'a> { /* private fields */ }Expand description
Use this method to send audio files, if you want Telegram clients to display them in the music player. Your audio must be in the .MP3 or .M4A format. On success, the sent Message is returned. Bots can currently send audio files of up to 50 MB in size, this limit may be changed in the future.
For sending voice messages, use the sendVoice method instead.
Implementations
Sourceimpl<'a> SendAudioRequest<'a>
impl<'a> SendAudioRequest<'a>
pub fn new( api: &'a API, chat_id: impl Into<ChatId>, audio: impl Into<InputFile>, ) -> Self
Sourcepub fn business_connection_id(
self,
business_connection_id: impl Into<String>,
) -> Self
pub fn business_connection_id( self, business_connection_id: impl Into<String>, ) -> Self
Unique identifier of the business connection on behalf of which the message will be sent
Sourcepub fn chat_id(self, chat_id: impl Into<ChatId>) -> Self
pub fn chat_id(self, chat_id: impl Into<ChatId>) -> Self
Unique identifier for the target chat or username of the target channel (in the format @channelusername)
Sourcepub fn message_thread_id(self, message_thread_id: impl Into<i64>) -> Self
pub fn message_thread_id(self, message_thread_id: impl Into<i64>) -> Self
Unique identifier for the target message thread (topic) of the forum; for forum supergroups only
Sourcepub fn audio(self, audio: impl Into<InputFile>) -> Self
pub fn audio(self, audio: impl Into<InputFile>) -> Self
Audio file to send. Pass a file_id as String to send an audio file that exists on the Telegram servers (recommended), pass an HTTP URL as a String for Telegram to get an audio file from the Internet, or upload a new one using multipart/form-data. More information on Sending Files »
Sourcepub fn caption(self, caption: impl Into<String>) -> Self
pub fn caption(self, caption: impl Into<String>) -> Self
Audio caption, 0-1024 characters after entities parsing
Sourcepub fn parse_mode(self, parse_mode: impl Into<String>) -> Self
pub fn parse_mode(self, parse_mode: impl Into<String>) -> Self
Mode for parsing entities in the audio caption. See formatting options for more details.
Sourcepub fn caption_entities(
self,
caption_entities: impl IntoIterator<Item = impl Into<MessageEntity>>,
) -> Self
pub fn caption_entities( self, caption_entities: impl IntoIterator<Item = impl Into<MessageEntity>>, ) -> Self
A JSON-serialized list of special entities that appear in the caption, which can be specified instead of parse_mode
Sourcepub fn thumbnail(self, thumbnail: impl Into<InputFile>) -> Self
pub fn thumbnail(self, thumbnail: impl Into<InputFile>) -> Self
Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail’s width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
Sourcepub fn disable_notification(self, disable_notification: impl Into<bool>) -> Self
pub fn disable_notification(self, disable_notification: impl Into<bool>) -> Self
Sends the message silently. Users will receive a notification with no sound.
Sourcepub fn protect_content(self, protect_content: impl Into<bool>) -> Self
pub fn protect_content(self, protect_content: impl Into<bool>) -> Self
Protects the contents of the sent message from forwarding and saving
Sourcepub fn allow_paid_broadcast(self, allow_paid_broadcast: impl Into<bool>) -> Self
pub fn allow_paid_broadcast(self, allow_paid_broadcast: impl Into<bool>) -> Self
Pass True to allow up to 1000 messages per second, ignoring broadcasting limits for a fee of 0.1 Telegram Stars per message. The relevant Stars will be withdrawn from the bot’s balance
Sourcepub fn message_effect_id(self, message_effect_id: impl Into<String>) -> Self
pub fn message_effect_id(self, message_effect_id: impl Into<String>) -> Self
Unique identifier of the message effect to be added to the message; for private chats only
Sourcepub fn reply_parameters(
self,
reply_parameters: impl Into<ReplyParameters>,
) -> Self
pub fn reply_parameters( self, reply_parameters: impl Into<ReplyParameters>, ) -> Self
Description of the message to reply to
Sourcepub fn reply_markup(self, reply_markup: impl Into<ReplyMarkup>) -> Self
pub fn reply_markup(self, reply_markup: impl Into<ReplyMarkup>) -> Self
Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove a reply keyboard or to force a reply from the user